FsError

Enum FsError 

pub enum FsError {
    Read {
        path: String,
        detail: String,
    },
    Write {
        path: String,
        detail: String,
    },
    Directory {
        path: String,
        detail: String,
    },
    Lock {
        path: String,
        detail: String,
    },
    PathResolution(String),
    InvalidRequest(String),
}
Error from an asynchronous filesystem operation.

Variants



Read

A file read operation failed.

Fields

path: String

The path involved in the failed operation.

detail: String

Human-readable operating-system detail.



Write

A file write operation failed.

Fields

path: String

The path involved in the failed operation.

detail: String

Human-readable operating-system detail.



Directory

A directory operation failed.

Fields

path: String

The directory involved in the failed operation.

detail: String

Human-readable operating-system detail.



Lock

A filesystem lock operation failed.

Fields

path: String

The lock path involved in the failed operation.

detail: String

Human-readable operating-system detail.



PathResolution(String)

A path could not be resolved before filesystem I/O began.



InvalidRequest(String)

A caller supplied an invalid bound or path relationship.

Implementations

Source

impl FsError

pub fn io(operation: Operation, path: &Path, detail: impl Display) -> Self

Construct an error with the appropriate operation and path context.