pub struct AsyncFile { /* private fields */ }Expand description
A file handle whose open, read, write, seek, flush, and metadata operations are all asynchronous.
Implementations
Sourceimpl AsyncFile
impl AsyncFile
Sourcepub async fn open(path: impl AsRef<Path>) -> Result<Self, FsError>
pub async fn open(path: impl AsRef<Path>) -> Result<Self, FsError>
Open an existing file for reading.
Sourcepub async fn open_if_exists(
path: impl AsRef<Path>,
) -> Result<Option<Self>, FsError>
pub async fn open_if_exists( path: impl AsRef<Path>, ) -> Result<Option<Self>, FsError>
Open an existing file, returning None when it does not exist.
Sourcepub async fn create(path: impl AsRef<Path>) -> Result<Self, FsError>
pub async fn create(path: impl AsRef<Path>) -> Result<Self, FsError>
Create or truncate a file for writing.
Sourcepub async fn create_new(path: impl AsRef<Path>) -> Result<Self, FsError>
pub async fn create_new(path: impl AsRef<Path>) -> Result<Self, FsError>
Create a new file, failing if it already exists.
Sourcepub async fn open_append(path: impl AsRef<Path>) -> Result<Self, FsError>
pub async fn open_append(path: impl AsRef<Path>) -> Result<Self, FsError>
Open a file for appending, creating it when needed.
Sourcepub async fn open_write_at_end(path: impl AsRef<Path>) -> Result<Self, FsError>
pub async fn open_write_at_end(path: impl AsRef<Path>) -> Result<Self, FsError>
Open a file for writing and position it at its current end.
Sourcepub async fn read_exact(&mut self, buffer: &mut [u8]) -> Result<(), FsError>
pub async fn read_exact(&mut self, buffer: &mut [u8]) -> Result<(), FsError>
Read exactly the requested number of bytes.
Sourcepub async fn write_all(&mut self, buffer: &[u8]) -> Result<(), FsError>
pub async fn write_all(&mut self, buffer: &[u8]) -> Result<(), FsError>
Write all bytes in buffer.
Sourcepub async fn flush(&mut self) -> Result<(), FsError>
pub async fn flush(&mut self) -> Result<(), FsError>
Flush buffered bytes to the operating system.
Sourcepub async fn sync_all(&self) -> Result<(), FsError>
pub async fn sync_all(&self) -> Result<(), FsError>
Flush file contents and metadata to stable storage.
Sourcepub async fn sync_data(&self) -> Result<(), FsError>
pub async fn sync_data(&self) -> Result<(), FsError>
Flush file contents to stable storage using the platform’s data-sync operation.
Sourcepub async fn seek(&mut self, position: SeekFrom) -> Result<u64, FsError>
pub async fn seek(&mut self, position: SeekFrom) -> Result<u64, FsError>
Seek to a position and return the new offset.
Sourcepub async fn stream_position(&mut self) -> Result<u64, FsError>
pub async fn stream_position(&mut self) -> Result<u64, FsError>
Return the current stream position.