DirectoryReader

Struct DirectoryReader 

pub struct DirectoryReader { /* private fields */ }
An asynchronous directory reader. Call Self::next repeatedly instead of collecting the directory into memory.

Implementations

Source

impl DirectoryReader

pub async fn open(path: impl AsRef<Path>) -> Result<Self, FsError>

Open a directory for asynchronous traversal.

pub async fn open_if_exists( path: impl AsRef<Path>, ) -> Result<Option<Self>, FsError>

Open a directory when it exists, returning None for a missing path.

pub async fn next(&mut self) -> Result<Option<DirectoryEntry>, FsError>

Read the next entry, returning None at end of directory.