pub enum FsError {
Read {
path: String,
detail: String,
},
Write {
path: String,
detail: String,
},
Directory {
path: String,
detail: String,
},
Lock {
path: String,
detail: String,
},
PathResolution(String),
InvalidRequest(String),
}Expand description
Error from an asynchronous filesystem operation.
Variants
Read
A file read operation failed.
Fields
Write
A file write operation failed.
Fields
Directory
A directory operation failed.
Fields
Lock
A filesystem lock operation failed.
Fields
PathResolution(String)
A path could not be resolved before filesystem I/O began.
InvalidRequest(String)
A caller supplied an invalid bound or path relationship.
Implementations