pub struct ExclusiveLock { /* private fields */ }Expand description
An acquired non-blocking exclusive advisory lock.
The operating-system lock is released when this value is dropped. The descriptor is intentionally private so callers cannot reintroduce direct synchronous filesystem access around the lock boundary.